@REM Build file for ClassicsJ2EE jar file, ejb_classics.jar
@REM This builds the origianl  JAR ---> BUILDS ORIGINAL JAR, WITH NO STUB <---
@REM Compiles .java files, builds a .jar file then creates a weblogic deployable .jar file
@REM The jar file is named ejb_classics.jar and is placed in the directory from where this 
@REM file is run (by default: C:\Classics\RQA Tests\RQA Weblogic Assets\Source)

@REM Brian Bryson, BBryson@Rational.Com
@REM Vancouver, BC, Canada
@REM Original   : 07-May-01, Rainier, v2001A
@REM Updated	: 25-Sep-01, Olympus Mons, v2002
@REM Last Update: 17-Jan-03, McKinley, v2003

@Echo off
	CLS
	@REM Setup classpath and environment variables

	@REM NOTE: This batch file overwrites MYCLASSPATH, removing refrence to ejb_classics.jar
	CALL UTL_SetEnv.BAT
@Echo On


@Echo Off
	@REM Copy over .XML deployment files

	Echo Copying XML deployment files.
	copy XMLFiles\. build\META-INF\. > nul
@Echo on


@Echo Off
	@REM Place Original CustomerHelper .java source files in source directory

	Echo Restoring CustomerHelper original source files.
	copy Backup\NoStub\*.java com\rational\cdshop\ejb\. > nul
@Echo on



@Echo Off
	@REM Compile ejb classes into the build directory from which the JAR file will be built

	Echo Compiling Java files with JDK javac utility.
	%JAVA_HOME%\bin\javac -d build -classpath %MYCLASSPATH% com\rational\cdshop\ejb\*.java
@Echo On
		
		
@Echo Off
	@REM Clean up previous JAR files from last build

	@REM Check for wl_ejb_classics.jar and build\wl_ejb_classics.jar
	if exist ejb_classics.jar echo Current Weblogic EJB JAR file will be deleted.
	if exist ejb_classics.jar del ejb_classics.jar
	
	@REM Check for build\wl_ejb_classics.jar
	if exist build\wl_ejb_classics.jar echo Current wl_ejb_classics.jar file will be deleted.
	if exist build\wl_ejb_classics.jar del build\wl_ejb_classics.jar
	
	@REM Check for build\std_ejb_classics.jar
	if exist build\std_ejb_classics.jar echo Current std_ejb_classics.jar file will be deleted.
	if exist build\std_ejb_classics.jar del build\std_ejb_classics.jar
	
	
@Echo On

@Echo Off
	@REM Make a standard ejb jar file, including XML deployment descriptors

	Echo Building JAR with JDK jar utility.
	cd build
	%JAVA_HOME%\bin\jar cv0fM std_ejb_classics.jar META-INF com > ..\BuildJarResults.txt
	cd ..
	
	type BuildJarResults.txt | find /c /i "error" > nul
	if errorlevel 1 goto NoBuildErrorsFound
	if errorlevel 0 goto BuildErrorsFound

	:BuildErrorsFound
	Echo Errors found, please examine BuildJarResults.txt
	goto End

	:NoBuildErrorsFound
	Echo JAR Build successful.
	del BuildJarResults.txt
	

@Echo Off
	@REM Run ejbc to create the deployable jar file
	
	@REM Set classpath for weblogic.ejbc.  Same as above without referenced to classics_ejb.jar
	@REM set MYCLASSPATH="%WL_HOME%"\weblogic700\server\lib\weblogic.jar;"%WL_HOME%"\user_projects\ClassicsJ2EE\applications\ejb_classics.jar;"%J2EE_HOME%"\lib\j2ee.jar;"%JAVA_HOME%"\jre\lib\rt.jar;"%RATL_RTHOME%"\rttssjava.jar;"%RATL_RTHOME%"\tsea\rttseajava.jar;"%RATL_RTHOME%"\QualityArchitect\rational_ct.jar;.
	set MYCLASSPATH="%WL_HOME%"\weblogic700\server\lib\weblogic.jar;"%J2EE_HOME%"\lib\j2ee.jar;"%JAVA_HOME%"\jre\lib\rt.jar;"%RATL_RTHOME%"\rttssjava.jar;"%RATL_RTHOME%"\tsea\rttseajava.jar;"%RATL_RTHOME%"\QualityArchitect\rational_ct.jar;.
	
	Echo Building Weblogic 7 deployable JAR with weblogic.ejbc utility.
	%JAVA_HOME%\bin\java -Dweblogic.home=%WL_HOME%\weblogic700\server -classpath %MYCLASSPATH% weblogic.ejbc -compiler %JAVA_HOME%\bin\javac -verbose -g build\std_ejb_classics.jar build\wl_ejb_classics.jar > WLEJBJarResults.txt

	type WLEJBJarResults.txt | find /c /i "failed" > nul
	if errorlevel 1 goto NoWLJARErrorsFound
	if errorlevel 0 goto WLJARErrorsFound

	:WLJARErrorsFound
	Echo Errors found, please examine WLEJBJarResults.txt
	goto End

	:NoWLJARErrorsFound
	Echo WebLogic Deployable JAR Build successful
	del WLEJBJarResults.txt
	copy build\wl_ejb_classics.jar ejb_classics.jar > nul
	Echo JAR file is in the Source directory
	
	@REM Delete temporary jar files
	if exist build\wl_ejb_classics.jar del build\wl_ejb_classics.jar
	if exist build\std_ejb_classics.jar del build\std_ejb_classics.jar
	
	goto End

@Echo On


:End
@Echo off
	@REM Reset system variables

	@REM NOTE: This batch file overwrites MYCLASSPATH, removing refrence to ejb_classics.jar
	CALL UTL_SetEnv.BAT
@Echo On
