package com.rational.cdshop.ejb;

import javax.naming.*;
import java.rmi.RemoteException;
// import java.security.Identity;
import java.util.Properties;
import javax.ejb.*;

/**
 * This is a Session Bean Class
 */
public class SearchCdBean implements SessionBean {
	private javax.ejb.SessionContext mySessionCtx = null;
	private final static long serialVersionUID = 3206093459760846163L;
	private final static String SEARCH_BY_COMPOSER = "composer";
	private final static String SEARCH_BY_PERFORMER = "performer";
	private final static String SEARCH_BY_COMPOSITION = "composition";

/**
 * ejbActivate method comment
 * @exception java.rmi.RemoteException The exception description.
 */
public void ejbActivate() throws java.rmi.RemoteException {
	
	System.out.println("SearchCd being activated");	
	
}
/**
 * ejbCreate method comment
 * @exception javax.ejb.CreateException The exception description.
 * @exception java.rmi.RemoteException The exception description.
 */
public void ejbCreate() throws javax.ejb.CreateException, java.rmi.RemoteException {

	System.out.println("SearchCd being created");
	
}
/**
 * ejbPassivate method comment
 * @exception java.rmi.RemoteException The exception description.
 */
public void ejbPassivate() throws java.rmi.RemoteException {
	
	System.out.println("SearchCd being passivated");
}
/**
 * ejbRemove method comment
 * @exception java.rmi.RemoteException The exception description.
 */
public void ejbRemove() throws java.rmi.RemoteException {

	System.out.println("SearchCd being removed");	
	
}
/**
 * Insert the method's description here.
 * Creation date: (2/9/2001 3:12:14 AM)
 * @param type java.lang.String
 * @exception java.rmi.RemoteException The exception description.
 */
public java.util.Enumeration executeSearch() throws java.rmi.RemoteException {

	// Execute the search using default values (search for all cds by composer with no sort)
	return executeSearch(SearchCdBean.SEARCH_BY_COMPOSER, "", "");
	
}
/**
 * Insert the method's description here.
 * Creation date: (2/9/2001 3:12:14 AM)
 * @param type java.lang.String
 * @exception java.rmi.RemoteException The exception description.
 */
public java.util.Enumeration executeSearch(String searchType, String searchFor, String sortType) throws java.rmi.RemoteException {

	java.util.Enumeration result = null;

	try {
		javax.naming.Context ctx = getInitialContext();
		CdHome home = (CdHome) ctx.lookup("Cd");

		if ((searchFor == null) || (searchFor.equals(""))) {
			result = home.findAll();
		}
		else if (searchType.equals(this.SEARCH_BY_COMPOSER)) {
			result = home.findByComposer(searchFor);
		}
		else if (searchType.equals(this.SEARCH_BY_COMPOSITION)) {
			result = home.findByComposition(searchFor);
		}
		else if (searchType.equals(this.SEARCH_BY_PERFORMER)) {
			result = home.findByPerformer(searchFor);
		}
	}
	catch (NamingException ne) {
		throw new RemoteException( "Unable to create CdHome", ne );
	} 
	catch (FinderException fe) {
		throw new RemoteException( "Unable to execute find method", fe);
	}

	return result;
	
}
/**
 * Insert the method's description here.
 * Creation date: (2/9/2001 3:29:32 AM)
 */
private Context getInitialContext() throws NamingException {
	
	Properties p = new Properties();

	p.setProperty(Context.PROVIDER_URL,"t3://localhost:7001");
	p.setProperty(Context.INITIAL_CONTEXT_FACTORY,"weblogic.jndi.WLInitialContextFactory");
		
	return new InitialContext(p);
		
}
/**
 * getSessionContext method comment
 * @return javax.ejb.SessionContext
 */
public javax.ejb.SessionContext getSessionContext() {
	return mySessionCtx;
}
/**
 * setSessionContext method comment
 * @param ctx javax.ejb.SessionContext
 * @exception java.rmi.RemoteException The exception description.
 */
public void setSessionContext(javax.ejb.SessionContext ctx) throws java.rmi.RemoteException {
	mySessionCtx = ctx;
}
}